======
pypums
======


.. image:: https://img.shields.io/pypi/v/pypums.svg
        :target: https://pypi.python.org/pypi/pypums

.. image:: https://img.shields.io/travis/chekos/pypums.svg
        :target: https://travis-ci.org/chekos/pypums

.. image:: https://readthedocs.org/projects/pypums/badge/?version=latest
        :target: https://pypums.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




Download Public Use Micro Sample (PUMS) data files from US Census Bureau's FTP server.


* Free software: MIT license
* Documentation: https://pypums.readthedocs.io.


Features
--------

* TODO
  * add support for multiple surveys. Right now it defaults to ACS only.


Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
